simplify

Package simplify |
[hide private]
[frames] | no frames]

# Package simplify

source code

Submodules | [hide private]
simplify.constants simplify.domain

Classes | [hide private]
| Authentication Holds authentication information used when accessing the API.
| AccessToken OAuth access token.
| ApiError Base class for all API errors.
| IllegalArgumentError Error raised when passing illegal arguments.
| ApiConnectionError Error raised when there are communication errors contacting the API.
| AuthenticationError Error raised where there are problems authentication a request.
| BadRequestError Error raised when the request contains errors.
| ObjectNotFoundError Error raised when a requested object cannot be found.
| NotAllowedError Error raised when a request was not allowed.
| SysError Error raised when there was a system error processing a request.
| Http
| Jws
| PaymentsApi
| Event A Event object.
| Authorization A Authorization object.
| CardToken A CardToken object.
| Coupon A Coupon object.
| Customer A Customer object.
| FraudCheck A FraudCheck object.
| Invoice A Invoice object.
| InvoiceItem A InvoiceItem object.
| Payment A Payment object.
| Plan A Plan object.
| Refund A Refund object.
| Subscription A Subscription object.
| Tax A Tax object.
| TransactionReview A TransactionReview object.
| Webhook A Webhook object.

Functions | [hide private]
build_query_string(criteria) | source code
handle_http_error(response_body, response_code) | source code

Variables | [hide private]
| HTTP_SUCCESS = `200`
| HTTP_REDIRECTED = `302`
| HTTP_UNAUTHORIZED = `401`
| HTTP_NOT_FOUND = `404`
| HTTP_NOT_ALLOWED = `405`
| HTTP_BAD_REQUEST = `400`
| HTTP_METHOD_POST = `"POST"`
| HTTP_METHOD_PUT = `"PUT"`
| HTTP_METHOD_GET = `"GET"`
| HTTP_METHOD_DELETE = `"DELETE"`
| public_key = `None`
| private_key = `None`
| api_base_sandbox_url = ``'``https://sandbox.simplify.com/v1/api``'``
| api_base_live_url = ``'``https://api.simplify.com/v1/api``'``
| oauth_base_url = ``'``https://www.simplify.com/commerce/oauth``'``
| user_agent = `None`